# VISCA-IP-Controller

Python code for controlling PTZ cameras using VISCA commands over a local network.

`pip install visca-over-ip`

[Documentation](https://visca-over-ip.readthedocs.io)

## Applications
If you are looking for a graphical program to control a camera, use [VISCA IP Controller GUI](https://github.com/misterhay/VISCA-IP-Controller-GUI). For joystick control use [Visca Joystick](https://github.com/International-Anglican-Church/visca-joystick).
